SphereEvidence

Struct SphereEvidence 

#[non_exhaustive]
pub struct SphereEvidence { pub support: Vec<usize>, pub error: f64, }
Which points determine the sphere and how exact the output is.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
support: Vec<usize>

Indices into the input of the one to four points the exact minimum sphere passes through and is determined by, ascending.

error: f64

A bound on the distance between the returned centre and the exact one, and on the returned radius’s excess over the exact radius. The returned radius is never below the exact radius, so the returned sphere contains every input point. Zero for a single point.