Enum ExactBRepError

#[non_exhaustive]
pub enum ExactBRepError { Empty, Topology(BRepHealth), MissingEdgeCurve { edge_index: usize, }, UnknownCurve3 { edge_index: usize, }, MissingEdgeInterval { edge_index: usize, }, InvalidEdgeInterval { edge_index: usize, }, MissingPcurve { loop_index: usize, use_index: usize, }, UnknownCurve2 { loop_index: usize, use_index: usize, }, MissingPcurveInterval { loop_index: usize, use_index: usize, }, InvalidPcurveInterval { loop_index: usize, use_index: usize, }, MissingFaceSurface { face_index: usize, }, UnknownSurface { face_index: usize, }, }
Why exact B-rep assembly was refused.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Empty

A result without faces is not a boundary representation.



Topology(BRepHealth)

Generic topology has unresolved handles or invalid loop/face structure.



MissingEdgeCurve

An edge did not state its exact three-dimensional support.

Fields

edge_index: usize


UnknownCurve3

An edge support handle does not resolve in the 3D curve catalog.

Fields

edge_index: usize


MissingEdgeInterval

An edge did not state its native support-curve interval.

Fields

edge_index: usize


InvalidEdgeInterval

An edge support interval was non-finite or zero-length.

Fields

edge_index: usize


MissingPcurve

An edge use did not state its trim curve in the owning face’s parameters.

Fields

loop_index: usize
use_index: usize


UnknownCurve2

A pcurve support handle does not resolve in the 2D curve catalog.

Fields

loop_index: usize
use_index: usize


MissingPcurveInterval

A pcurve did not state its native interval.

Fields

loop_index: usize
use_index: usize


InvalidPcurveInterval

A pcurve interval was non-finite or zero-length.

Fields

loop_index: usize
use_index: usize


MissingFaceSurface

A face did not state its exact support surface.

Fields

face_index: usize


UnknownSurface

A face support handle does not resolve in the surface catalog.

Fields

face_index: usize