Function tapered_revolve

pub fn tapered_revolve(
    start: &Rings,
    end: &Rings,
    axis_origin: Point3,
    axis_direction: Vec3,
    angle: Scalar,
    tolerance: Tolerance,
) -> GeomResult<TriMesh>
Revolve between two profiles.

Unlike a plain revolution this can never close: a full turn would have to meet the start profile with the end profile, which are different by construction. It is always capped.