pub struct ExactBRepBuilder { /* private fields */ }Expand description
Mutable assembly state that can only yield an ExactBRep after validation.
Implementations
Sourceimpl ExactBRepBuilder
impl ExactBRepBuilder
Sourcepub fn try_reserve(
&mut self,
curves3: usize,
curves2: usize,
surfaces: usize,
edge_intervals: usize,
pcurve_intervals: usize,
) -> Result<(), TryReserveError>
pub fn try_reserve( &mut self, curves3: usize, curves2: usize, surfaces: usize, edge_intervals: usize, pcurve_intervals: usize, ) -> Result<(), TryReserveError>
Fallibly reserve owned support and interval catalogs for bounded assembly.
Sourcepub fn add_curve3(&mut self, curve: Curve3) -> Curve3Id
pub fn add_curve3(&mut self, curve: Curve3) -> Curve3Id
Store an exact 3D curve support.
Sourcepub fn add_curve2(&mut self, curve: Curve2) -> Curve2Id
pub fn add_curve2(&mut self, curve: Curve2) -> Curve2Id
Store an exact 2D pcurve support.
Sourcepub fn add_surface(&mut self, surface: Surface) -> SurfaceId
pub fn add_surface(&mut self, surface: Surface) -> SurfaceId
Store an exact surface support.
Sourcepub fn topology_mut(&mut self) -> &mut BRep<Curve3Id, Curve2Id, SurfaceId>
pub fn topology_mut(&mut self) -> &mut BRep<Curve3Id, Curve2Id, SurfaceId>
Mutable typed topology under construction. Self::finish validates it.
Sourcepub fn set_edge_interval(&mut self, edge: EdgeId, interval: Interval)
pub fn set_edge_interval(&mut self, edge: EdgeId, interval: Interval)
State an edge’s finite native curve span.
Sourcepub fn set_pcurve_interval(
&mut self,
loop_id: LoopId,
use_index: usize,
interval: Interval,
)
pub fn set_pcurve_interval( &mut self, loop_id: LoopId, use_index: usize, interval: Interval, )
State an edge use’s finite native pcurve span in its loop traversal order.
Sourcepub fn finish(self) -> Result<ExactBRep, ExactBRepError>
pub fn finish(self) -> Result<ExactBRep, ExactBRepError>
Validate and freeze the exact B-rep result.